import React from "react";

import Card from "./Card";
import CardListColumn from "./cardlist/CardListColumn";
import CardListGrid from "./cardlist/CardListGrid";
import CardListRow from "./cardlist/CardListRow";


interface CardProps {
    to?: string;
    className?: string;
    anime?: boolean;
    side?: boolean;
    icon?: string;
    title?: string;
    content?: string;
}

interface Props {
    cards?: CardProps[];
    layout?: 'row' | 'col' | 'grid';
    className?: string;
}


const oComponents = {
    'row': CardListRow,
    'col': CardListColumn,
    'grid': CardListGrid
}


const CardList = (props: Props) => {
    const {
        cards = [],
        layout = 'row',
        className = ''
    } = props;
    
    const CardListComponent = oComponents[layout];

    const listCards = cards.map((card, index) => {
        let tmpProps = {
            side: false,
            anime: true,
            className: ''
        };
        
        if (layout == 'row') {
            tmpProps = {
                side: true,
                anime: false,
                className: 'max-w-full'
            };
        }

        let cardProps = {
            ...card, 
            ...tmpProps
        };

        return (
            <Card
                key={index}
                {...cardProps}
            />
        )
    })

    return (
        <CardListComponent
            className={className}
        >
            {listCards}
        </CardListComponent>
    )
};


export default CardList;